Struct WpColorManagementOutputV1
pub struct WpColorManagementOutputV1 { /* private fields */ }wayland and Linux only.Expand description
output color properties
A wp_color_management_output_v1 describes the color properties of an output.
The wp_color_management_output_v1 is associated with the wl_output global underlying the wl_output object. Therefore the client destroying the wl_output object has no impact, but the compositor removing the output global makes the wp_color_management_output_v1 object inert.
See also the Event enum for this interface.
Implementations
impl WpColorManagementOutputV1
impl WpColorManagementOutputV1
pub fn destroy(&self)
pub fn destroy(&self)
destroy the color management output
Destroy the color wp_color_management_output_v1 object. This does not affect any remaining protocol objects.
pub fn get_image_description<U, D>(
&self,
qh: &QueueHandle<D>,
udata: U,
) -> WpImageDescriptionV1
pub fn get_image_description<U, D>( &self, qh: &QueueHandle<D>, udata: U, ) -> WpImageDescriptionV1
get the image description of the output
This creates a new wp_image_description_v1 object for the current image description of the output. There always is exactly one image description active for an output so the client should destroy the image description created by earlier invocations of this request. This request is usually sent as a reaction to the image_description_changed event or when creating a wp_color_management_output_v1 object.
The image description of an output represents the color encoding the output expects. There might be performance and power advantages, as well as improved color reproduction, if a content update matches the image description of the output it is being shown on. If a content update is shown on any other output than the one it matches the image description of, then the color reproduction on those outputs might be considerably worse.
The created wp_image_description_v1 object preserves the image description of the output from the time the object was created.
The resulting image description object allows get_information request.
If this protocol object is inert, the resulting image description object shall immediately deliver the wp_image_description_v1.failed event with the no_output cause.
If the interface version is inadequate for the output’s image description, meaning that the client does not support all the events needed to deliver the crucial information, the resulting image description object shall immediately deliver the wp_image_description_v1.failed event with the low_version cause.
Otherwise the object shall immediately deliver the ready event.